pub fn project_kind_of(
fs: &dyn FileSystemService,
dir: &Path,
) -> Result<ProjectKind, FsError>Expand description
Detect the project type of one directory without walking up.
pub fn project_kind_of(
fs: &dyn FileSystemService,
dir: &Path,
) -> Result<ProjectKind, FsError>Detect the project type of one directory without walking up.