pub struct PaneGeometry {
pub sidebar_pct: u16,
pub bottom_pct: u16,
pub agent_pct: u16,
/* private fields */
}Expand description
Persisted pane percentages. Kept in the workspace crate so session persistence does not make the state crate depend on the UI crate.
Fields
bottom_pct: u16agent_pct: u16Implementations